@@ -4,6 +4,7 @@ require("fitdistrplus")
 visualize <- FALSE # TRUE for manual test with visualization of plots
 nsample <- 1000
 nsample <- 10
+set.seed(123) # here just to make random sampling reproducible
 
 # (1) Plot various distributions fitted to serving size data
 #
@@ -132,7 +133,7 @@ if (visualize)
   
   # graph 2
   f1 <- fitdist(x1,"norm")
-  f2 <- fitdist(x1,"gumbel", start = list(a = 10, b = 5))
+  f2 <- fitdist(x1,"gumbel", start = list(a = 10, b = 5)) # warning: The pgumbel function should have its first argument named: q as in base R
   f3 <- fitdist(x1, "exp")
   denscomp(list(f1, f2, f3), xlim = c(0, 30), fitlty = 1, legendtext = c("Normal","Gumbel","Exp"))
   
@@ -165,7 +166,6 @@ if (visualize)
   
   
   #basic normal distribution
-  set.seed(1234)
   x2 <- c(rnorm(nsample, 5),  rnorm(nsample, 10))
   #MLE fit
   fit1 <- fitdist(x2, "norm2", "mle", start=list(poid=1/3, m1=4, s1=2, m2=8, s2=2),
@@ -205,7 +205,7 @@ if (visualize)
 {
   # 'graphics' plot style
   denscomp(list(fit1, fit2, fit3), plotstyle = "gr")
-  denscomp(list(fit1, fit2, fit3), title = "Fitted distribution")
+  denscomp(list(fit1, fit2, fit3), main = "Fitted distribution")
   denscomp(list(fit1, fit2, fit3), main = "Fitted distribution", addlegend = F, demp = T, dempcol = "purple")
   
   # 'ggplot' plot style
@@ -244,7 +244,11 @@ if (visualize)
 x <- c(rpois(nsample, 5), rbinom(nsample, 12, 2/3))
 fpois <- fitdist(x, "pois")
 fgeo <- fitdist(x, "geom")
-fnbinom <- fitdist(x, "nbinom")
+fnbinom <- fitdist(x, "nbinom") 
+# Messages d'avis :Messages d'avis :
+# 1: Dans cov2cor(varcovar) :
+#   diag(V) had non-positive or NA entries; the non-finite result may be dubious
+# 2: Dans sqrt(diag(varcovar)) : Production de NaN
 
 par(mar=c(4,4,2,1))
 denscomp(list(fpois, fnbinom, fgeo), probability = TRUE)
@@ -351,3 +355,4 @@ if (requireNamespace ("ggplot2", quietly = TRUE)) {
   denscomp(list(fitW, fitln, fitg), plotstyle = "ggplot", fitlty = 1, fitlwd = 3:1)
   denscomp(list(fitW, fitln, fitg), plotstyle = "ggplot", fitlty = 1, fitlwd = 1:3, fitcol = c(1:2, 7))
 }
+
