@@ -2,6 +2,7 @@ require("fitdistrplus")
 visualize <- FALSE # TRUE for manual tests with visualization of results
 nsample <- 10000
 nsample <- 10
+set.seed(123) # here just to make random sampling reproducible
 
 # (1) tests with the Burr distribution (three parameters)
 #
@@ -27,7 +28,6 @@ if(any(installed.packages()[, "Package"] == "actuar"))
 
 # (2) An example on discrete data with or without weights
 #
-set.seed(1234)
 x <- rpois(nsample, 10)
 xtab <- table(x)
 xval <- sort(unique(x))
@@ -64,4 +64,22 @@ if(visualize)
   llplot(fa, fit.show = TRUE, loglik = FALSE)
   llplot(fb, fit.show = TRUE, loglik = FALSE) # should give the same
   
+}
+
+# (4) An example with NaN stderror
+# 
+
+if(visualize)
+{
+  claims <- read.csv("~/Documents/recherche-enseignement/code/R/riskassessment/bug/20250107/Claims.csv")
+  x <- claims$UltimateCost/1000
+  
+  fit_B_mle <- fitdist(x, "burr", method="mle", lower=0)
+  llplot(fit_B_mle, expansion = 10, fit.show = TRUE)
+  
+  fit_IB_mle <- fitdist(x, "invburr", method="mle", lower=0) # converges to a wrong solution
+  llplot(fit_IB_mle, expansion = 10, fit.show = TRUE)
+  
+  fit_IB_mle$estimate[1] <- NaN
+  llplot(fit_IB_mle, expansion = 10, fit.show = TRUE)
 }
\ No newline at end of file
