@@ -1,5 +1,5 @@
 require("fitdistrplus")
-set.seed(123)
+set.seed(123) # here just to make random sampling reproducible
 n <- 20
 visualize <- FALSE # TRUE for manual tests with visualization of results
 if (visualize)
